@@ -30,6 +30,7 @@ from geneticengine.grammars.sgp import Var
 from geneticengine.metahandlers.vars import VarRange
 from geneticengine.metrics import f1_score
 from geneticengine.metrics import mse
+from geneticengine.off_the_shelf.sympy_compatible import fix_all
 
 
 class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
@@ -162,6 +163,7 @@ class GeneticProgrammingRegressor(BaseEstimator, TransformerMixin):
 
         best_ind, fitness, phenotype = model.evolve(verbose=1)
         self.evolved_phenotype = phenotype
+        self.sympy_compatible_phenotype = fix_all(str(phenotype))
 
     def predict(self, X):
         """
@@ -279,6 +281,7 @@ class HillClimbingRegressor(BaseEstimator, TransformerMixin):
 
         best_ind, fitness, phenotype = model.evolve(verbose=1)
         self.evolved_phenotype = phenotype
+        self.sympy_compatible_phenotype = fix_all(str(phenotype))
 
     def predict(self, X):
         """
@@ -301,24 +304,3 @@ class HillClimbingRegressor(BaseEstimator, TransformerMixin):
 
         return y_pred
 
-
-DATASET_NAME = "Vladislavleva4"
-DATA_FILE_TRAIN = f"examples/data/{DATASET_NAME}/Train.txt"
-DATA_FILE_TEST = f"examples/data/{DATASET_NAME}/Test.txt"
-
-bunch = pd.read_csv(DATA_FILE_TRAIN, delimiter="\t")
-target = bunch.response
-data = bunch.drop(["response"], axis=1)
-
-
-print("GP Regressor")
-model = GeneticProgrammingRegressor()
-model.fit(data, target)
-print(model.predict(data.iloc[0:5]))
-print(target.iloc[0:5].values)
-
-print("HC Regressor")
-model = HillClimbingRegressor()
-model.fit(data, target)
-print(model.predict(data.iloc[0:5]))
-print(target.iloc[0:5].values)
